==> apache-beam-2.43.0-source-release.zip: beam-2.43.0/playground/frontend/playground_components/lib/src/widgets/toggle_theme_icon_button.dart <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:provider/provider.dart';

import '../constants/playground_components.dart';
import '../constants/sizes.dart';
import '../generated/assets.gen.dart';
import '../theme/switch_notifier.dart';

class ToggleThemeIconButton extends StatelessWidget {
  const ToggleThemeIconButton({super.key});

  @override
  Widget build(BuildContext context) {
    return Consumer<ThemeSwitchNotifier>(builder: (context, notifier, child) {
      return IconButton(
        iconSize: BeamIconSizes.large,
        splashRadius: BeamIconSizes.largeSplashRadius,
        icon: SvgPicture.asset(
          Assets.buttons.themeMode,
          package: PlaygroundComponents.packageName,
        ),
        onPressed: notifier.toggleTheme,
      );
    });
  }
}

==> apache-beam-2.45.0-source-release.zip: beam-2.45.0/playground/frontend/playground_components/lib/src/widgets/toggle_theme_icon_button.dart <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:provider/provider.dart';

import '../assets/assets.gen.dart';
import '../constants/sizes.dart';
import '../playground_components.dart';
import '../theme/switch_notifier.dart';

class ToggleThemeIconButton extends StatelessWidget {
  const ToggleThemeIconButton({super.key});

  @override
  Widget build(BuildContext context) {
    return Consumer<ThemeSwitchNotifier>(
      builder: (context, notifier, child) {
        return IconButton(
          iconSize: BeamIconSizes.large,
          splashRadius: BeamIconSizes.largeSplashRadius,
          icon: SvgPicture.asset(
            Assets.buttons.themeMode,
            package: PlaygroundComponents.packageName,
          ),
          onPressed: notifier.toggleTheme,
        );
      },
    );
  }
}
